# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/cronreport/v1/cronreport.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/cronreport/v1/cronreport.proto',
  package='github.com.metaprov.modelaapi.services.cronreport.v1',
  syntax='proto3',
  serialized_options=b'Z4github.com/metaprov/modelaapi/services/cronreport/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nEgithub.com/metaprov/modelaapi/services/cronreport/v1/cronreport.proto\x12\x34github.com.metaprov.modelaapi.services.cronreport.v1\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\"\xd2\x01\n\x16ListCronReportsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12h\n\x06labels\x18\x03 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"r\n\x17ListCronReportsResponse\x12W\n\x05items\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReportList\"\x1a\n\x18\x43reateCronReportResponse\"m\n\x17\x43reateCronReportRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\"m\n\x17UpdateCronReportRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\"\x1a\n\x18UpdateCronReportResponse\"7\n\x14GetCronReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"y\n\x15GetCronReportResponse\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\x12\x0c\n\x04yaml\x18\x02 \x01(\t\":\n\x17\x44\x65leteCronReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteCronReportResponse\"9\n\x16PauseCronReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x19\n\x17PauseCronReportResponse\":\n\x17ResumeCronReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18ResumeCronReportResponse\"j\n\x14RunCronReportRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\"\x17\n\x15RunCronReportResponse2\xb4\r\n\x11\x43ronReportService\x12\xc7\x01\n\x0fListCronReports\x12L.github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsRequest\x1aM.github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/cronreports\x12\xcd\x01\n\x10\x43reateCronReport\x12M.github.com.metaprov.modelaapi.services.cronreport.v1.CreateCronReportRequest\x1aN.github.com.metaprov.modelaapi.services.cronreport.v1.CreateCronReportResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/cronreports:\x01*\x12\xc8\x01\n\rGetCronReport\x12J.github.com.metaprov.modelaapi.services.cronreport.v1.GetCronReportRequest\x1aK.github.com.metaprov.modelaapi.services.cronreport.v1.GetCronReportResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/cronreports/{name}\x12\xe8\x01\n\x10UpdateCronReport\x12M.github.com.metaprov.modelaapi.services.cronreport.v1.UpdateCronReportRequest\x1aN.github.com.metaprov.modelaapi.services.cronreport.v1.UpdateCronReportResponse\"5\x82\xd3\xe4\x93\x02/\x1a*/v1/cronreports/{cronreport.metadata.name}:\x01*\x12\xd1\x01\n\x10\x44\x65leteCronReport\x12M.github.com.metaprov.modelaapi.services.cronreport.v1.DeleteCronReportRequest\x1aN.github.com.metaprov.modelaapi.services.cronreport.v1.DeleteCronReportResponse\"\x1e\x82\xd3\xe4\x93\x02\x18*\x16/v1/cronreports/{name}\x12\xc8\x01\n\tRunReport\x12J.github.com.metaprov.modelaapi.services.cronreport.v1.RunCronReportRequest\x1aK.github.com.metaprov.modelaapi.services.cronreport.v1.RunCronReportResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/v1/cronreports/{name}:run\x12\xd4\x01\n\x0fPauseCronReport\x12L.github.com.metaprov.modelaapi.services.cronreport.v1.PauseCronReportRequest\x1aM.github.com.metaprov.modelaapi.services.cronreport.v1.PauseCronReportResponse\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/v1/cronreports/{name}:pause\x12\xd8\x01\n\x10ResumeCronReport\x12M.github.com.metaprov.modelaapi.services.cronreport.v1.ResumeCronReportRequest\x1aN.github.com.metaprov.modelaapi.services.cronreport.v1.ResumeCronReportResponse\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/v1/cronreports/{name}:resumeB6Z4github.com/metaprov/modelaapi/services/cronreport/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTCRONREPORTSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=397,
  serialized_end=442,
)

_LISTCRONREPORTSREQUEST = _descriptor.Descriptor(
  name='ListCronReportsRequest',
  full_name='github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTCRONREPORTSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=232,
  serialized_end=442,
)


_LISTCRONREPORTSRESPONSE = _descriptor.Descriptor(
  name='ListCronReportsResponse',
  full_name='github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=444,
  serialized_end=558,
)


_CREATECRONREPORTRESPONSE = _descriptor.Descriptor(
  name='CreateCronReportResponse',
  full_name='github.com.metaprov.modelaapi.services.cronreport.v1.CreateCronReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=560,
  serialized_end=586,
)


_CREATECRONREPORTREQUEST = _descriptor.Descriptor(
  name='CreateCronReportRequest',
  full_name='github.com.metaprov.modelaapi.services.cronreport.v1.CreateCronReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.cronreport.v1.CreateCronReportRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=588,
  serialized_end=697,
)


_UPDATECRONREPORTREQUEST = _descriptor.Descriptor(
  name='UpdateCronReportRequest',
  full_name='github.com.metaprov.modelaapi.services.cronreport.v1.UpdateCronReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.cronreport.v1.UpdateCronReportRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=699,
  serialized_end=808,
)


_UPDATECRONREPORTRESPONSE = _descriptor.Descriptor(
  name='UpdateCronReportResponse',
  full_name='github.com.metaprov.modelaapi.services.cronreport.v1.UpdateCronReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=810,
  serialized_end=836,
)


_GETCRONREPORTREQUEST = _descriptor.Descriptor(
  name='GetCronReportRequest',
  full_name='github.com.metaprov.modelaapi.services.cronreport.v1.GetCronReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.cronreport.v1.GetCronReportRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.cronreport.v1.GetCronReportRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=838,
  serialized_end=893,
)


_GETCRONREPORTRESPONSE = _descriptor.Descriptor(
  name='GetCronReportResponse',
  full_name='github.com.metaprov.modelaapi.services.cronreport.v1.GetCronReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.cronreport.v1.GetCronReportResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.cronreport.v1.GetCronReportResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=895,
  serialized_end=1016,
)


_DELETECRONREPORTREQUEST = _descriptor.Descriptor(
  name='DeleteCronReportRequest',
  full_name='github.com.metaprov.modelaapi.services.cronreport.v1.DeleteCronReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.cronreport.v1.DeleteCronReportRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.cronreport.v1.DeleteCronReportRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1018,
  serialized_end=1076,
)


_DELETECRONREPORTRESPONSE = _descriptor.Descriptor(
  name='DeleteCronReportResponse',
  full_name='github.com.metaprov.modelaapi.services.cronreport.v1.DeleteCronReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1078,
  serialized_end=1104,
)


_PAUSECRONREPORTREQUEST = _descriptor.Descriptor(
  name='PauseCronReportRequest',
  full_name='github.com.metaprov.modelaapi.services.cronreport.v1.PauseCronReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.cronreport.v1.PauseCronReportRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.cronreport.v1.PauseCronReportRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1106,
  serialized_end=1163,
)


_PAUSECRONREPORTRESPONSE = _descriptor.Descriptor(
  name='PauseCronReportResponse',
  full_name='github.com.metaprov.modelaapi.services.cronreport.v1.PauseCronReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1165,
  serialized_end=1190,
)


_RESUMECRONREPORTREQUEST = _descriptor.Descriptor(
  name='ResumeCronReportRequest',
  full_name='github.com.metaprov.modelaapi.services.cronreport.v1.ResumeCronReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.cronreport.v1.ResumeCronReportRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.cronreport.v1.ResumeCronReportRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1192,
  serialized_end=1250,
)


_RESUMECRONREPORTRESPONSE = _descriptor.Descriptor(
  name='ResumeCronReportResponse',
  full_name='github.com.metaprov.modelaapi.services.cronreport.v1.ResumeCronReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1252,
  serialized_end=1278,
)


_RUNCRONREPORTREQUEST = _descriptor.Descriptor(
  name='RunCronReportRequest',
  full_name='github.com.metaprov.modelaapi.services.cronreport.v1.RunCronReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.cronreport.v1.RunCronReportRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1280,
  serialized_end=1386,
)


_RUNCRONREPORTRESPONSE = _descriptor.Descriptor(
  name='RunCronReportResponse',
  full_name='github.com.metaprov.modelaapi.services.cronreport.v1.RunCronReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1388,
  serialized_end=1411,
)

_LISTCRONREPORTSREQUEST_LABELSENTRY.containing_type = _LISTCRONREPORTSREQUEST
_LISTCRONREPORTSREQUEST.fields_by_name['labels'].message_type = _LISTCRONREPORTSREQUEST_LABELSENTRY
_LISTCRONREPORTSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._CRONREPORTLIST
_CREATECRONREPORTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._CRONREPORT
_UPDATECRONREPORTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._CRONREPORT
_GETCRONREPORTRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._CRONREPORT
_RUNCRONREPORTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._CRONREPORT
DESCRIPTOR.message_types_by_name['ListCronReportsRequest'] = _LISTCRONREPORTSREQUEST
DESCRIPTOR.message_types_by_name['ListCronReportsResponse'] = _LISTCRONREPORTSRESPONSE
DESCRIPTOR.message_types_by_name['CreateCronReportResponse'] = _CREATECRONREPORTRESPONSE
DESCRIPTOR.message_types_by_name['CreateCronReportRequest'] = _CREATECRONREPORTREQUEST
DESCRIPTOR.message_types_by_name['UpdateCronReportRequest'] = _UPDATECRONREPORTREQUEST
DESCRIPTOR.message_types_by_name['UpdateCronReportResponse'] = _UPDATECRONREPORTRESPONSE
DESCRIPTOR.message_types_by_name['GetCronReportRequest'] = _GETCRONREPORTREQUEST
DESCRIPTOR.message_types_by_name['GetCronReportResponse'] = _GETCRONREPORTRESPONSE
DESCRIPTOR.message_types_by_name['DeleteCronReportRequest'] = _DELETECRONREPORTREQUEST
DESCRIPTOR.message_types_by_name['DeleteCronReportResponse'] = _DELETECRONREPORTRESPONSE
DESCRIPTOR.message_types_by_name['PauseCronReportRequest'] = _PAUSECRONREPORTREQUEST
DESCRIPTOR.message_types_by_name['PauseCronReportResponse'] = _PAUSECRONREPORTRESPONSE
DESCRIPTOR.message_types_by_name['ResumeCronReportRequest'] = _RESUMECRONREPORTREQUEST
DESCRIPTOR.message_types_by_name['ResumeCronReportResponse'] = _RESUMECRONREPORTRESPONSE
DESCRIPTOR.message_types_by_name['RunCronReportRequest'] = _RUNCRONREPORTREQUEST
DESCRIPTOR.message_types_by_name['RunCronReportResponse'] = _RUNCRONREPORTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListCronReportsRequest = _reflection.GeneratedProtocolMessageType('ListCronReportsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTCRONREPORTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTCRONREPORTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsRequest)
  })
_sym_db.RegisterMessage(ListCronReportsRequest)
_sym_db.RegisterMessage(ListCronReportsRequest.LabelsEntry)

ListCronReportsResponse = _reflection.GeneratedProtocolMessageType('ListCronReportsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCRONREPORTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsResponse)
  })
_sym_db.RegisterMessage(ListCronReportsResponse)

CreateCronReportResponse = _reflection.GeneratedProtocolMessageType('CreateCronReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECRONREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.CreateCronReportResponse)
  })
_sym_db.RegisterMessage(CreateCronReportResponse)

CreateCronReportRequest = _reflection.GeneratedProtocolMessageType('CreateCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.CreateCronReportRequest)
  })
_sym_db.RegisterMessage(CreateCronReportRequest)

UpdateCronReportRequest = _reflection.GeneratedProtocolMessageType('UpdateCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.UpdateCronReportRequest)
  })
_sym_db.RegisterMessage(UpdateCronReportRequest)

UpdateCronReportResponse = _reflection.GeneratedProtocolMessageType('UpdateCronReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECRONREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.UpdateCronReportResponse)
  })
_sym_db.RegisterMessage(UpdateCronReportResponse)

GetCronReportRequest = _reflection.GeneratedProtocolMessageType('GetCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.GetCronReportRequest)
  })
_sym_db.RegisterMessage(GetCronReportRequest)

GetCronReportResponse = _reflection.GeneratedProtocolMessageType('GetCronReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCRONREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.GetCronReportResponse)
  })
_sym_db.RegisterMessage(GetCronReportResponse)

DeleteCronReportRequest = _reflection.GeneratedProtocolMessageType('DeleteCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.DeleteCronReportRequest)
  })
_sym_db.RegisterMessage(DeleteCronReportRequest)

DeleteCronReportResponse = _reflection.GeneratedProtocolMessageType('DeleteCronReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETECRONREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.DeleteCronReportResponse)
  })
_sym_db.RegisterMessage(DeleteCronReportResponse)

PauseCronReportRequest = _reflection.GeneratedProtocolMessageType('PauseCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSECRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.PauseCronReportRequest)
  })
_sym_db.RegisterMessage(PauseCronReportRequest)

PauseCronReportResponse = _reflection.GeneratedProtocolMessageType('PauseCronReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSECRONREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.PauseCronReportResponse)
  })
_sym_db.RegisterMessage(PauseCronReportResponse)

ResumeCronReportRequest = _reflection.GeneratedProtocolMessageType('ResumeCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMECRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.ResumeCronReportRequest)
  })
_sym_db.RegisterMessage(ResumeCronReportRequest)

ResumeCronReportResponse = _reflection.GeneratedProtocolMessageType('ResumeCronReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMECRONREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.ResumeCronReportResponse)
  })
_sym_db.RegisterMessage(ResumeCronReportResponse)

RunCronReportRequest = _reflection.GeneratedProtocolMessageType('RunCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNCRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.RunCronReportRequest)
  })
_sym_db.RegisterMessage(RunCronReportRequest)

RunCronReportResponse = _reflection.GeneratedProtocolMessageType('RunCronReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNCRONREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.RunCronReportResponse)
  })
_sym_db.RegisterMessage(RunCronReportResponse)


DESCRIPTOR._options = None
_LISTCRONREPORTSREQUEST_LABELSENTRY._options = None

_CRONREPORTSERVICE = _descriptor.ServiceDescriptor(
  name='CronReportService',
  full_name='github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1414,
  serialized_end=3130,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListCronReports',
    full_name='github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService.ListCronReports',
    index=0,
    containing_service=None,
    input_type=_LISTCRONREPORTSREQUEST,
    output_type=_LISTCRONREPORTSRESPONSE,
    serialized_options=b'\202\323\344\223\002\021\022\017/v1/cronreports',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateCronReport',
    full_name='github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService.CreateCronReport',
    index=1,
    containing_service=None,
    input_type=_CREATECRONREPORTREQUEST,
    output_type=_CREATECRONREPORTRESPONSE,
    serialized_options=b'\202\323\344\223\002\024\"\017/v1/cronreports:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCronReport',
    full_name='github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService.GetCronReport',
    index=2,
    containing_service=None,
    input_type=_GETCRONREPORTREQUEST,
    output_type=_GETCRONREPORTRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/v1/cronreports/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateCronReport',
    full_name='github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService.UpdateCronReport',
    index=3,
    containing_service=None,
    input_type=_UPDATECRONREPORTREQUEST,
    output_type=_UPDATECRONREPORTRESPONSE,
    serialized_options=b'\202\323\344\223\002/\032*/v1/cronreports/{cronreport.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteCronReport',
    full_name='github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService.DeleteCronReport',
    index=4,
    containing_service=None,
    input_type=_DELETECRONREPORTREQUEST,
    output_type=_DELETECRONREPORTRESPONSE,
    serialized_options=b'\202\323\344\223\002\030*\026/v1/cronreports/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RunReport',
    full_name='github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService.RunReport',
    index=5,
    containing_service=None,
    input_type=_RUNCRONREPORTREQUEST,
    output_type=_RUNCRONREPORTRESPONSE,
    serialized_options=b'\202\323\344\223\002\034\"\032/v1/cronreports/{name}:run',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PauseCronReport',
    full_name='github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService.PauseCronReport',
    index=6,
    containing_service=None,
    input_type=_PAUSECRONREPORTREQUEST,
    output_type=_PAUSECRONREPORTRESPONSE,
    serialized_options=b'\202\323\344\223\002\036\"\034/v1/cronreports/{name}:pause',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResumeCronReport',
    full_name='github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService.ResumeCronReport',
    index=7,
    containing_service=None,
    input_type=_RESUMECRONREPORTREQUEST,
    output_type=_RESUMECRONREPORTRESPONSE,
    serialized_options=b'\202\323\344\223\002\037\"\035/v1/cronreports/{name}:resume',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CRONREPORTSERVICE)

DESCRIPTOR.services_by_name['CronReportService'] = _CRONREPORTSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/curtain/v1/curtain.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/curtain/v1/curtain.proto',
  package='github.com.metaprov.modelaapi.services.curtain.v1',
  syntax='proto3',
  serialized_options=b'Z1github.com/metaprov/modelaapi/services/curtain/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n?github.com/metaprov/modelaapi/services/curtain/v1/curtain.proto\x12\x31github.com.metaprov.modelaapi.services.curtain.v1\x1a\x1cgoogle/api/annotations.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\"\xe2\x01\n\x13ListCurtainsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x62\n\x06labels\x18\x02 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x86\x01\n\x14ListCurtainsResponse\x12U\n\x05items\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CurtainList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x17\n\x15\x43reateCurtainResponse\"h\n\x14\x43reateCurtainRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Curtain\"h\n\x14UpdateCurtainRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Curtain\"\x17\n\x15UpdateCurtainResponse\"4\n\x11GetCurtainRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"t\n\x12GetCurtainResponse\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Curtain\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"7\n\x14\x44\x65leteCurtainRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteCurtainResponse2\x98\x08\n\x0e\x43urtainService\x12\xb5\x01\n\x0cListCurtains\x12\x46.github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsRequest\x1aG.github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/curtains\x12\xc1\x01\n\rCreateCurtain\x12G.github.com.metaprov.modelaapi.services.curtain.v1.CreateCurtainRequest\x1aH.github.com.metaprov.modelaapi.services.curtain.v1.CreateCurtainResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x0c/v1/curtains:\x07\x63urtain\x12\xc2\x01\n\nGetCurtain\x12\x44.github.com.metaprov.modelaapi.services.curtain.v1.GetCurtainRequest\x1a\x45.github.com.metaprov.modelaapi.services.curtain.v1.GetCurtainResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/curtains/{namespace}/{name}\x12\xf6\x01\n\rUpdateCurtain\x12G.github.com.metaprov.modelaapi.services.curtain.v1.UpdateCurtainRequest\x1aH.github.com.metaprov.modelaapi.services.curtain.v1.UpdateCurtainResponse\"R\x82\xd3\xe4\x93\x02L\x1a\x41/v1/curtains/{curtain.metadata.namespace}/{curtain.metadata.name}:\x07\x63urtain\x12\xcb\x01\n\rDeleteCurtain\x12G.github.com.metaprov.modelaapi.services.curtain.v1.DeleteCurtainRequest\x1aH.github.com.metaprov.modelaapi.services.curtain.v1.DeleteCurtainResponse\"\'\x82\xd3\xe4\x93\x02!*\x1f/v1/curtains/{namespace}/{name}B3Z1github.com/metaprov/modelaapi/services/curtain/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTCURTAINSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=405,
  serialized_end=450,
)

_LISTCURTAINSREQUEST = _descriptor.Descriptor(
  name='ListCurtainsRequest',
  full_name='github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsRequest.page_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsRequest.page_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTCURTAINSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=450,
)


_LISTCURTAINSRESPONSE = _descriptor.Descriptor(
  name='ListCurtainsResponse',
  full_name='github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=453,
  serialized_end=587,
)


_CREATECURTAINRESPONSE = _descriptor.Descriptor(
  name='CreateCurtainResponse',
  full_name='github.com.metaprov.modelaapi.services.curtain.v1.CreateCurtainResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=589,
  serialized_end=612,
)


_CREATECURTAINREQUEST = _descriptor.Descriptor(
  name='CreateCurtainRequest',
  full_name='github.com.metaprov.modelaapi.services.curtain.v1.CreateCurtainRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.curtain.v1.CreateCurtainRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=614,
  serialized_end=718,
)


_UPDATECURTAINREQUEST = _descriptor.Descriptor(
  name='UpdateCurtainRequest',
  full_name='github.com.metaprov.modelaapi.services.curtain.v1.UpdateCurtainRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.curtain.v1.UpdateCurtainRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=720,
  serialized_end=824,
)


_UPDATECURTAINRESPONSE = _descriptor.Descriptor(
  name='UpdateCurtainResponse',
  full_name='github.com.metaprov.modelaapi.services.curtain.v1.UpdateCurtainResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=826,
  serialized_end=849,
)


_GETCURTAINREQUEST = _descriptor.Descriptor(
  name='GetCurtainRequest',
  full_name='github.com.metaprov.modelaapi.services.curtain.v1.GetCurtainRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.curtain.v1.GetCurtainRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.curtain.v1.GetCurtainRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=851,
  serialized_end=903,
)


_GETCURTAINRESPONSE = _descriptor.Descriptor(
  name='GetCurtainResponse',
  full_name='github.com.metaprov.modelaapi.services.curtain.v1.GetCurtainResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.curtain.v1.GetCurtainResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.curtain.v1.GetCurtainResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=905,
  serialized_end=1021,
)


_DELETECURTAINREQUEST = _descriptor.Descriptor(
  name='DeleteCurtainRequest',
  full_name='github.com.metaprov.modelaapi.services.curtain.v1.DeleteCurtainRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.curtain.v1.DeleteCurtainRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.curtain.v1.DeleteCurtainRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1023,
  serialized_end=1078,
)


_DELETECURTAINRESPONSE = _descriptor.Descriptor(
  name='DeleteCurtainResponse',
  full_name='github.com.metaprov.modelaapi.services.curtain.v1.DeleteCurtainResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1080,
  serialized_end=1103,
)

_LISTCURTAINSREQUEST_LABELSENTRY.containing_type = _LISTCURTAINSREQUEST
_LISTCURTAINSREQUEST.fields_by_name['labels'].message_type = _LISTCURTAINSREQUEST_LABELSENTRY
_LISTCURTAINSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._CURTAINLIST
_CREATECURTAINREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._CURTAIN
_UPDATECURTAINREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._CURTAIN
_GETCURTAINRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._CURTAIN
DESCRIPTOR.message_types_by_name['ListCurtainsRequest'] = _LISTCURTAINSREQUEST
DESCRIPTOR.message_types_by_name['ListCurtainsResponse'] = _LISTCURTAINSRESPONSE
DESCRIPTOR.message_types_by_name['CreateCurtainResponse'] = _CREATECURTAINRESPONSE
DESCRIPTOR.message_types_by_name['CreateCurtainRequest'] = _CREATECURTAINREQUEST
DESCRIPTOR.message_types_by_name['UpdateCurtainRequest'] = _UPDATECURTAINREQUEST
DESCRIPTOR.message_types_by_name['UpdateCurtainResponse'] = _UPDATECURTAINRESPONSE
DESCRIPTOR.message_types_by_name['GetCurtainRequest'] = _GETCURTAINREQUEST
DESCRIPTOR.message_types_by_name['GetCurtainResponse'] = _GETCURTAINRESPONSE
DESCRIPTOR.message_types_by_name['DeleteCurtainRequest'] = _DELETECURTAINREQUEST
DESCRIPTOR.message_types_by_name['DeleteCurtainResponse'] = _DELETECURTAINRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListCurtainsRequest = _reflection.GeneratedProtocolMessageType('ListCurtainsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTCURTAINSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTCURTAINSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsRequest)
  })
_sym_db.RegisterMessage(ListCurtainsRequest)
_sym_db.RegisterMessage(ListCurtainsRequest.LabelsEntry)

ListCurtainsResponse = _reflection.GeneratedProtocolMessageType('ListCurtainsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCURTAINSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsResponse)
  })
_sym_db.RegisterMessage(ListCurtainsResponse)

CreateCurtainResponse = _reflection.GeneratedProtocolMessageType('CreateCurtainResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECURTAINRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.CreateCurtainResponse)
  })
_sym_db.RegisterMessage(CreateCurtainResponse)

CreateCurtainRequest = _reflection.GeneratedProtocolMessageType('CreateCurtainRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECURTAINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.CreateCurtainRequest)
  })
_sym_db.RegisterMessage(CreateCurtainRequest)

UpdateCurtainRequest = _reflection.GeneratedProtocolMessageType('UpdateCurtainRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECURTAINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.UpdateCurtainRequest)
  })
_sym_db.RegisterMessage(UpdateCurtainRequest)

UpdateCurtainResponse = _reflection.GeneratedProtocolMessageType('UpdateCurtainResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECURTAINRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.UpdateCurtainResponse)
  })
_sym_db.RegisterMessage(UpdateCurtainResponse)

GetCurtainRequest = _reflection.GeneratedProtocolMessageType('GetCurtainRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCURTAINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.GetCurtainRequest)
  })
_sym_db.RegisterMessage(GetCurtainRequest)

GetCurtainResponse = _reflection.GeneratedProtocolMessageType('GetCurtainResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCURTAINRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.GetCurtainResponse)
  })
_sym_db.RegisterMessage(GetCurtainResponse)

DeleteCurtainRequest = _reflection.GeneratedProtocolMessageType('DeleteCurtainRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECURTAINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.DeleteCurtainRequest)
  })
_sym_db.RegisterMessage(DeleteCurtainRequest)

DeleteCurtainResponse = _reflection.GeneratedProtocolMessageType('DeleteCurtainResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETECURTAINRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.DeleteCurtainResponse)
  })
_sym_db.RegisterMessage(DeleteCurtainResponse)


DESCRIPTOR._options = None
_LISTCURTAINSREQUEST_LABELSENTRY._options = None

_CURTAINSERVICE = _descriptor.ServiceDescriptor(
  name='CurtainService',
  full_name='github.com.metaprov.modelaapi.services.curtain.v1.CurtainService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1106,
  serialized_end=2154,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListCurtains',
    full_name='github.com.metaprov.modelaapi.services.curtain.v1.CurtainService.ListCurtains',
    index=0,
    containing_service=None,
    input_type=_LISTCURTAINSREQUEST,
    output_type=_LISTCURTAINSRESPONSE,
    serialized_options=b'\202\323\344\223\002\016\022\014/v1/curtains',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateCurtain',
    full_name='github.com.metaprov.modelaapi.services.curtain.v1.CurtainService.CreateCurtain',
    index=1,
    containing_service=None,
    input_type=_CREATECURTAINREQUEST,
    output_type=_CREATECURTAINRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\"\014/v1/curtains:\007curtain',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCurtain',
    full_name='github.com.metaprov.modelaapi.services.curtain.v1.CurtainService.GetCurtain',
    index=2,
    containing_service=None,
    input_type=_GETCURTAINREQUEST,
    output_type=_GETCURTAINRESPONSE,
    serialized_options=b'\202\323\344\223\002!\022\037/v1/curtains/{namespace}/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateCurtain',
    full_name='github.com.metaprov.modelaapi.services.curtain.v1.CurtainService.UpdateCurtain',
    index=3,
    containing_service=None,
    input_type=_UPDATECURTAINREQUEST,
    output_type=_UPDATECURTAINRESPONSE,
    serialized_options=b'\202\323\344\223\002L\032A/v1/curtains/{curtain.metadata.namespace}/{curtain.metadata.name}:\007curtain',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteCurtain',
    full_name='github.com.metaprov.modelaapi.services.curtain.v1.CurtainService.DeleteCurtain',
    index=4,
    containing_service=None,
    input_type=_DELETECURTAINREQUEST,
    output_type=_DELETECURTAINRESPONSE,
    serialized_options=b'\202\323\344\223\002!*\037/v1/curtains/{namespace}/{name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CURTAINSERVICE)

DESCRIPTOR.services_by_name['CurtainService'] = _CURTAINSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/virtualbucket/v1/virtualbucket.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/virtualbucket/v1/virtualbucket.proto',
  package='github.com.metaprov.modelaapi.services.virtualbucket.v1',
  syntax='proto3',
  serialized_options=b'Z7github.com/metaprov/modelaapi/services/virtualbucket/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nKgithub.com/metaprov/modelaapi/services/virtualbucket/v1/virtualbucket.proto\x12\x37github.com.metaprov.modelaapi.services.virtualbucket.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\"\xcd\x01\n\x19ListVirtualBucketsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12n\n\x06labels\x18\x02 \x03(\x0b\x32^.github.com.metaprov.modelaapi.services.virtualbucket.v1.ListVirtualBucketsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"u\n\x1aListVirtualBucketsResponse\x12W\n\x05items\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucketList\"p\n\x1a\x43reateVirtualBucketRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\"\x1d\n\x1b\x43reateVirtualBucketResponse\"p\n\x1aUpdateVirtualBucketRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\"\x1d\n\x1bUpdateVirtualBucketResponse\":\n\x17GetVirtualBucketRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"|\n\x18GetVirtualBucketResponse\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"=\n\x1a\x44\x65leteVirtualBucketRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1b\x44\x65leteVirtualBucketResponse2\xae\t\n\x14VirtualBucketService\x12\xd9\x01\n\x12ListVirtualBuckets\x12R.github.com.metaprov.modelaapi.services.virtualbucket.v1.ListVirtualBucketsRequest\x1aS.github.com.metaprov.modelaapi.services.virtualbucket.v1.ListVirtualBucketsResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/virtualbuckets\x12\xdf\x01\n\x13\x43reateVirtualBucket\x12S.github.com.metaprov.modelaapi.services.virtualbucket.v1.CreateVirtualBucketRequest\x1aT.github.com.metaprov.modelaapi.services.virtualbucket.v1.CreateVirtualBucketResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/virtualbuckets:\x01*\x12\xda\x01\n\x10GetVirtualBucket\x12P.github.com.metaprov.modelaapi.services.virtualbucket.v1.GetVirtualBucketRequest\x1aQ.github.com.metaprov.modelaapi.services.virtualbucket.v1.GetVirtualBucketResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/virtualbuckets/{name}\x12\xfd\x01\n\x13UpdateVirtualBucket\x12S.github.com.metaprov.modelaapi.services.virtualbucket.v1.UpdateVirtualBucketRequest\x1aT.github.com.metaprov.modelaapi.services.virtualbucket.v1.UpdateVirtualBucketResponse\";\x82\xd3\xe4\x93\x02\x35\x1a\x30/v1/virtualbuckets/{virtualbucket.metadata.name}:\x01*\x12\xfa\x01\n\x13\x44\x65leteVirtualBucket\x12S.github.com.metaprov.modelaapi.services.virtualbucket.v1.DeleteVirtualBucketRequest\x1aT.github.com.metaprov.modelaapi.services.virtualbucket.v1.DeleteVirtualBucketResponse\"8\x82\xd3\xe4\x93\x02\x32*0/v1/virtualbuckets/{virtualbucket.metadata.name}B9Z7github.com/metaprov/modelaapi/services/virtualbucket/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTVIRTUALBUCKETSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.ListVirtualBucketsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.ListVirtualBucketsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.ListVirtualBucketsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=398,
  serialized_end=443,
)

_LISTVIRTUALBUCKETSREQUEST = _descriptor.Descriptor(
  name='ListVirtualBucketsRequest',
  full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.ListVirtualBucketsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.ListVirtualBucketsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.ListVirtualBucketsRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTVIRTUALBUCKETSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=443,
)


_LISTVIRTUALBUCKETSRESPONSE = _descriptor.Descriptor(
  name='ListVirtualBucketsResponse',
  full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.ListVirtualBucketsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.ListVirtualBucketsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=445,
  serialized_end=562,
)


_CREATEVIRTUALBUCKETREQUEST = _descriptor.Descriptor(
  name='CreateVirtualBucketRequest',
  full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.CreateVirtualBucketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.CreateVirtualBucketRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=564,
  serialized_end=676,
)


_CREATEVIRTUALBUCKETRESPONSE = _descriptor.Descriptor(
  name='CreateVirtualBucketResponse',
  full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.CreateVirtualBucketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=678,
  serialized_end=707,
)


_UPDATEVIRTUALBUCKETREQUEST = _descriptor.Descriptor(
  name='UpdateVirtualBucketRequest',
  full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.UpdateVirtualBucketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.UpdateVirtualBucketRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=709,
  serialized_end=821,
)


_UPDATEVIRTUALBUCKETRESPONSE = _descriptor.Descriptor(
  name='UpdateVirtualBucketResponse',
  full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.UpdateVirtualBucketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=823,
  serialized_end=852,
)


_GETVIRTUALBUCKETREQUEST = _descriptor.Descriptor(
  name='GetVirtualBucketRequest',
  full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.GetVirtualBucketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.GetVirtualBucketRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.GetVirtualBucketRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=854,
  serialized_end=912,
)


_GETVIRTUALBUCKETRESPONSE = _descriptor.Descriptor(
  name='GetVirtualBucketResponse',
  full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.GetVirtualBucketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.GetVirtualBucketResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.GetVirtualBucketResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=914,
  serialized_end=1038,
)


_DELETEVIRTUALBUCKETREQUEST = _descriptor.Descriptor(
  name='DeleteVirtualBucketRequest',
  full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.DeleteVirtualBucketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.DeleteVirtualBucketRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.DeleteVirtualBucketRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1040,
  serialized_end=1101,
)


_DELETEVIRTUALBUCKETRESPONSE = _descriptor.Descriptor(
  name='DeleteVirtualBucketResponse',
  full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.DeleteVirtualBucketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1103,
  serialized_end=1132,
)

_LISTVIRTUALBUCKETSREQUEST_LABELSENTRY.containing_type = _LISTVIRTUALBUCKETSREQUEST
_LISTVIRTUALBUCKETSREQUEST.fields_by_name['labels'].message_type = _LISTVIRTUALBUCKETSREQUEST_LABELSENTRY
_LISTVIRTUALBUCKETSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKETLIST
_CREATEVIRTUALBUCKETREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_UPDATEVIRTUALBUCKETREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_GETVIRTUALBUCKETRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
DESCRIPTOR.message_types_by_name['ListVirtualBucketsRequest'] = _LISTVIRTUALBUCKETSREQUEST
DESCRIPTOR.message_types_by_name['ListVirtualBucketsResponse'] = _LISTVIRTUALBUCKETSRESPONSE
DESCRIPTOR.message_types_by_name['CreateVirtualBucketRequest'] = _CREATEVIRTUALBUCKETREQUEST
DESCRIPTOR.message_types_by_name['CreateVirtualBucketResponse'] = _CREATEVIRTUALBUCKETRESPONSE
DESCRIPTOR.message_types_by_name['UpdateVirtualBucketRequest'] = _UPDATEVIRTUALBUCKETREQUEST
DESCRIPTOR.message_types_by_name['UpdateVirtualBucketResponse'] = _UPDATEVIRTUALBUCKETRESPONSE
DESCRIPTOR.message_types_by_name['GetVirtualBucketRequest'] = _GETVIRTUALBUCKETREQUEST
DESCRIPTOR.message_types_by_name['GetVirtualBucketResponse'] = _GETVIRTUALBUCKETRESPONSE
DESCRIPTOR.message_types_by_name['DeleteVirtualBucketRequest'] = _DELETEVIRTUALBUCKETREQUEST
DESCRIPTOR.message_types_by_name['DeleteVirtualBucketResponse'] = _DELETEVIRTUALBUCKETRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListVirtualBucketsRequest = _reflection.GeneratedProtocolMessageType('ListVirtualBucketsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTVIRTUALBUCKETSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.virtualbucket.v1.virtualbucket_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualbucket.v1.ListVirtualBucketsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTVIRTUALBUCKETSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualbucket.v1.virtualbucket_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualbucket.v1.ListVirtualBucketsRequest)
  })
_sym_db.RegisterMessage(ListVirtualBucketsRequest)
_sym_db.RegisterMessage(ListVirtualBucketsRequest.LabelsEntry)

ListVirtualBucketsResponse = _reflection.GeneratedProtocolMessageType('ListVirtualBucketsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALBUCKETSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualbucket.v1.virtualbucket_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualbucket.v1.ListVirtualBucketsResponse)
  })
_sym_db.RegisterMessage(ListVirtualBucketsResponse)

CreateVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('CreateVirtualBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualbucket.v1.virtualbucket_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualbucket.v1.CreateVirtualBucketRequest)
  })
_sym_db.RegisterMessage(CreateVirtualBucketRequest)

CreateVirtualBucketResponse = _reflection.GeneratedProtocolMessageType('CreateVirtualBucketResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALBUCKETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualbucket.v1.virtualbucket_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualbucket.v1.CreateVirtualBucketResponse)
  })
_sym_db.RegisterMessage(CreateVirtualBucketResponse)

UpdateVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('UpdateVirtualBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualbucket.v1.virtualbucket_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualbucket.v1.UpdateVirtualBucketRequest)
  })
_sym_db.RegisterMessage(UpdateVirtualBucketRequest)

UpdateVirtualBucketResponse = _reflection.GeneratedProtocolMessageType('UpdateVirtualBucketResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTUALBUCKETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualbucket.v1.virtualbucket_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualbucket.v1.UpdateVirtualBucketResponse)
  })
_sym_db.RegisterMessage(UpdateVirtualBucketResponse)

GetVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('GetVirtualBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualbucket.v1.virtualbucket_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualbucket.v1.GetVirtualBucketRequest)
  })
_sym_db.RegisterMessage(GetVirtualBucketRequest)

GetVirtualBucketResponse = _reflection.GeneratedProtocolMessageType('GetVirtualBucketResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALBUCKETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualbucket.v1.virtualbucket_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualbucket.v1.GetVirtualBucketResponse)
  })
_sym_db.RegisterMessage(GetVirtualBucketResponse)

DeleteVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('DeleteVirtualBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualbucket.v1.virtualbucket_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualbucket.v1.DeleteVirtualBucketRequest)
  })
_sym_db.RegisterMessage(DeleteVirtualBucketRequest)

DeleteVirtualBucketResponse = _reflection.GeneratedProtocolMessageType('DeleteVirtualBucketResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTUALBUCKETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualbucket.v1.virtualbucket_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualbucket.v1.DeleteVirtualBucketResponse)
  })
_sym_db.RegisterMessage(DeleteVirtualBucketResponse)


DESCRIPTOR._options = None
_LISTVIRTUALBUCKETSREQUEST_LABELSENTRY._options = None

_VIRTUALBUCKETSERVICE = _descriptor.ServiceDescriptor(
  name='VirtualBucketService',
  full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.VirtualBucketService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1135,
  serialized_end=2333,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListVirtualBuckets',
    full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.VirtualBucketService.ListVirtualBuckets',
    index=0,
    containing_service=None,
    input_type=_LISTVIRTUALBUCKETSREQUEST,
    output_type=_LISTVIRTUALBUCKETSRESPONSE,
    serialized_options=b'\202\323\344\223\002\024\022\022/v1/virtualbuckets',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateVirtualBucket',
    full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.VirtualBucketService.CreateVirtualBucket',
    index=1,
    containing_service=None,
    input_type=_CREATEVIRTUALBUCKETREQUEST,
    output_type=_CREATEVIRTUALBUCKETRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\"\022/v1/virtualbuckets:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetVirtualBucket',
    full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.VirtualBucketService.GetVirtualBucket',
    index=2,
    containing_service=None,
    input_type=_GETVIRTUALBUCKETREQUEST,
    output_type=_GETVIRTUALBUCKETRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/v1/virtualbuckets/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateVirtualBucket',
    full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.VirtualBucketService.UpdateVirtualBucket',
    index=3,
    containing_service=None,
    input_type=_UPDATEVIRTUALBUCKETREQUEST,
    output_type=_UPDATEVIRTUALBUCKETRESPONSE,
    serialized_options=b'\202\323\344\223\0025\0320/v1/virtualbuckets/{virtualbucket.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteVirtualBucket',
    full_name='github.com.metaprov.modelaapi.services.virtualbucket.v1.VirtualBucketService.DeleteVirtualBucket',
    index=4,
    containing_service=None,
    input_type=_DELETEVIRTUALBUCKETREQUEST,
    output_type=_DELETEVIRTUALBUCKETRESPONSE,
    serialized_options=b'\202\323\344\223\0022*0/v1/virtualbuckets/{virtualbucket.metadata.name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VIRTUALBUCKETSERVICE)

DESCRIPTOR.services_by_name['VirtualBucketService'] = _VIRTUALBUCKETSERVICE

# @@protoc_insertion_point(module_scope)
